# Session

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | 
**name** | **str** |  | 
**created_at** | **datetime** |  | 
**snapshots_history** | [**list[AppliedSnapshot]**](AppliedSnapshot.md) |  | 
**metrics_dashboard_url** | **str** |  | [optional] 
**jupyter_notebook_url** | **str** |  | [optional] 
**service_proxy_url** | **str** |  | [optional] 
**access_token** | **str** |  | [optional] 
**ray_dashboard_url** | **str** |  | [optional] 
**tensorboard_available** | **bool** |  | 
**project_id** | **str** |  | 
**head_node_ip** | **str** |  | [optional] 
**state** | [**SessionState**](SessionState.md) |  | 
**state_data** | [**SessionStateData**](SessionStateData.md) |  | [optional] 
**last_activity_at** | **datetime** |  | 
**cloud_id** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


